from setuptools import setup

setup(name='nanoint_distributions',
      version='0.2',
      description='Gaussian and Binomial distributions',
      packages=['distributions'],
      author='Nursultan Agzhigitov',
      author_email = 'nursultan.agzhigitov@gmail.com',
      zip_safe=False)
